==> audiochain-1.1.5-src.tgz: org/audiochain/ui/gui/AudioDeviceValueComponent.java <==
/**
   AudioChain Copyright (C) 2012-2013 Florian Paul (www.audiochain.org)
   
   This program is free software; you can redistribute it and/or modify it under the terms of the 
   GNU General Public License as published by the Free Software Foundation; either version 3 of the 
   License, or (at your option) any later version.
   
   This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without 
   even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General 
   Public License for more details.
   
   You should have received a copy of the GNU General Public License along with this program; 
   if not, see <http://www.gnu.org/licenses/>. 
 */
package org.audiochain.ui.gui;

import static javax.swing.SwingConstants.*;
import static org.audiochain.ui.gui.CommonComponentFactory.*;

import java.awt.Dimension;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.KeyAdapter;
import java.awt.event.KeyEvent;

import javax.swing.Box;
import javax.swing.BoxLayout;
import javax.swing.JCheckBox;
import javax.swing.JComboBox;
import javax.swing.JLabel;
import javax.swing.JTextField;

import org.audiochain.model.AudioDevice;
import org.audiochain.model.AudioDeviceValue;
import org.audiochain.model.AudioDeviceValueListener;
import org.audiochain.model.BooleanAudioDeviceValue;
import org.audiochain.model.EnumAudioDeviceValue;
import org.audiochain.model.FloatAudioDeviceValue;
import org.audiochain.model.IntAudioDeviceValue;
import org.audiochain.model.StringAudioDeviceValue;


public class AudioDeviceValueComponent extends Box {
	private static final long serialVersionUID = 1L;
	private AudioDeviceValue audioDeviceValue;

	public AudioDeviceValueComponent(AudioDeviceValue audioDeviceValue) {
		super(BoxLayout.Y_AXIS);
		this.audioDeviceValue = audioDeviceValue;
		init();
	}

	private void init() {
		setOpaque(false);
		if (audioDeviceValue instanceof FloatAudioDeviceValue) {
			createComponent((FloatAudioDeviceValue) audioDeviceValue);
		} else if (audioDeviceValue instanceof IntAudioDeviceValue) {
			createComponent((IntAudioDeviceValue) audioDeviceValue);
		} else if (audioDeviceValue instanceof BooleanAudioDeviceValue) {
			createComponent((BooleanAudioDeviceValue) audioDeviceValue);
		} else if (audioDeviceValue instanceof EnumAudioDeviceValue) {
			createComponent((EnumAudioDeviceValue<?>) audioDeviceValue);
		} else if (audioDeviceValue instanceof StringAudioDeviceValue) {
			createComponent((StringAudioDeviceValue) audioDeviceValue);
		} else {
			add(createLabel(audioDeviceValue.getName()));
		}
	}

	private void createComponent(final FloatAudioDeviceValue facv) {
		final LabeledRotaryPotentiometerComponent comp = new LabeledRotaryPotentiometerComponent(facv.getName(), facv.getMidValue());
		RotaryPotentiometerImageComponent poti = comp.getPotentiometer();
		poti.setUnit(facv.getUnit());
		poti.setScale(facv.getScale());
		add(comp);
		
		Float minValue = facv.getMinValue();
		if (minValue != null) {
			poti.setMinValue(minValue);
		}

		Float maxValue = facv.getMaxValue();
		if (maxValue != null) {
			poti.setMaxValue(maxValue);
		}

		comp.setValue(facv.getValue());
		poti.addValueChangeListener(new RotaryPotentiometerValueChangeListener() {
			@Override
			public void rotaryPotentiometerValueChanged(float newValue, float oldValue) {
				facv.setValue(newValue);
			}
		});
		facv.addAudioDeviceValueListener(new AudioDeviceValueListener() {
			@Override
			public void audioDeviceValueChanged(AudioDevice audioDevice, AudioDeviceValue audioDeviceValue, String oldValue, String newValue) {
				comp.setValue(facv.getValue());
			}
		});
	}

	private void createComponent(final IntAudioDeviceValue iacv) {
		Float mid = iacv.getMidValue() == null ? null : (float) iacv.getMidValue();
		final LabeledRotaryPotentiometerComponent comp = new LabeledRotaryPotentiometerComponent(iacv.getName(), mid);
		RotaryPotentiometerImageComponent poti = comp.getPotentiometer();
		poti.setUnit(iacv.getUnit());
		poti.setIntegralValue(true);
		add(comp);

		Integer minValue = iacv.getMinValue();
		if (minValue != null) {
			poti.setMinValue(minValue);
		}

		Integer maxValue = iacv.getMaxValue();
		if (maxValue != null) {
			poti.setMaxValue(maxValue);
		}

		comp.setValue(iacv.getValue());
		poti.addValueChangeListener(new RotaryPotentiometerValueChangeListener() {
			@Override
			public void rotaryPotentiometerValueChanged(float newValue, float oldValue) {
				iacv.setValue((int) newValue);
			}
		});
		iacv.addAudioDeviceValueListener(new AudioDeviceValueListener() {
			@Override
			public void audioDeviceValueChanged(AudioDevice audioDevice, AudioDeviceValue audioDeviceValue, String oldValue, String newValue) {
				comp.setValue(iacv.getValue());
			}
		});
	}

	private void createComponent(final BooleanAudioDeviceValue bacv) {
		final JCheckBox check = new LightEmittingDiodeCheckBox(bacv.getName(), bacv.getValue(), 8, 8);
		check.setAlignmentX(CENTER_ALIGNMENT);
		
		bacv.addAudioDeviceValueListener(new AudioDeviceValueListener() {
			@Override
			public void audioDeviceValueChanged(AudioDevice audioDevice, AudioDeviceValue audioDeviceValue, String oldValue, String newValue) {
				check.setSelected(bacv.getValue());
			}
		});
		check.addActionListener(new ActionListener() {
			@Override
			public void actionPerformed(ActionEvent e) {
				bacv.setValue(check.isSelected());
			}
		});
		add(check);
	}

	private void createComponent(final EnumAudioDeviceValue<?> eacv) {
		final JComboBox combo = createComboBox(eacv.getOptions());

		combo.setSelectedItem(eacv.getValue());
		combo.addActionListener(new ActionListener() {
			@Override
			public void actionPerformed(ActionEvent e) {
				eacv.setValueAsString(((Enum<?>) combo.getSelectedItem()).name());
			}
		});

		add(createLabel(eacv.getName()));
		add(combo);
		
		String value = eacv.getValueAsString();
		setToolTipText(value);
		combo.setToolTipText(value);
		eacv.addAudioDeviceValueListener(new AudioDeviceValueListener() {
			@Override
			public void audioDeviceValueChanged(AudioDevice audioDevice, AudioDeviceValue audioDeviceValue, String oldValue, String newValue) {
				String value = eacv.getValueAsString();
				setToolTipText(value);
				combo.setToolTipText(value);
				combo.setSelectedItem(eacv.getValue());
			}
		});
	}
	
	private void createComponent(final StringAudioDeviceValue sacv) {
		final JTextField textField = new JTextField(sacv.getValueAsString());
		textField.setAlignmentX(CENTER_ALIGNMENT);
		textField.setHorizontalAlignment(CENTER);
		Dimension dim = new Dimension(textField.getPreferredSize());
		dim.width = Integer.MAX_VALUE;
		textField.setMaximumSize(dim);
		textField.setBorder(null);
		textField.setOpaque(false);
		add(createLabel(sacv.getName()));
		add(textField);
		textField.addKeyListener(new KeyAdapter() {
			@Override
			public void keyReleased(KeyEvent e) {
				String text = textField.getText();
				if (text.trim().isEmpty()) {
					text = null;
				}
				sacv.setValueAsString(text);
			}
		});
		sacv.addAudioDeviceValueListener(new AudioDeviceValueListener() {
			@Override
			public void audioDeviceValueChanged(AudioDevice audioDevice, AudioDeviceValue audioDeviceValue, String oldValue, String newValue) {
				String value = sacv.getValueAsString();
				textField.setText(value);
			}
		});
	}

	private static JLabel createLabel(String text) {
		JLabel label = new JLabel(text);
		label.setAlignmentX(CENTER_ALIGNMENT);
		return label;
	}

}

==> audiochain-1.1.6-src.tgz: org/audiochain/ui/gui/AudioDeviceValueComponent.java <==
/**
   AudioChain Copyright (C) 2012-2013 Florian Paul (www.audiochain.org)
   
   This program is free software; you can redistribute it and/or modify it under the terms of the 
   GNU General Public License as published by the Free Software Foundation; either version 3 of the 
   License, or (at your option) any later version.
   
   This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without 
   even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General 
   Public License for more details.
   
   You should have received a copy of the GNU General Public License along with this program; 
   if not, see <http://www.gnu.org/licenses/>. 
 */
package org.audiochain.ui.gui;

import static javax.swing.SwingConstants.CENTER;
import static org.audiochain.ui.gui.CommonComponentFactory.createComboBox;

import java.awt.Dimension;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.KeyAdapter;
import java.awt.event.KeyEvent;

import javax.swing.Box;
import javax.swing.BoxLayout;
import javax.swing.JCheckBox;
import javax.swing.JComboBox;
import javax.swing.JLabel;
import javax.swing.JTextField;

import org.audiochain.model.AudioDevice;
import org.audiochain.model.AudioDeviceValue;
import org.audiochain.model.AudioDeviceValueListener;
import org.audiochain.model.BooleanAudioDeviceValue;
import org.audiochain.model.EnumAudioDeviceValue;
import org.audiochain.model.FloatAudioDeviceValue;
import org.audiochain.model.IntAudioDeviceValue;
import org.audiochain.model.StringAudioDeviceValue;


public class AudioDeviceValueComponent extends Box {
	private static final long serialVersionUID = 1L;
	private AudioDeviceValue audioDeviceValue;

	public AudioDeviceValueComponent(AudioDeviceValue audioDeviceValue) {
		super(BoxLayout.Y_AXIS);
		this.audioDeviceValue = audioDeviceValue;
		init();
	}

	private void init() {
		setOpaque(false);
		if (audioDeviceValue instanceof FloatAudioDeviceValue) {
			createComponent((FloatAudioDeviceValue) audioDeviceValue);
		} else if (audioDeviceValue instanceof IntAudioDeviceValue) {
			createComponent((IntAudioDeviceValue) audioDeviceValue);
		} else if (audioDeviceValue instanceof BooleanAudioDeviceValue) {
			createComponent((BooleanAudioDeviceValue) audioDeviceValue);
		} else if (audioDeviceValue instanceof EnumAudioDeviceValue) {
			createComponent((EnumAudioDeviceValue<?>) audioDeviceValue);
		} else if (audioDeviceValue instanceof StringAudioDeviceValue) {
			createComponent((StringAudioDeviceValue) audioDeviceValue);
		} else {
			add(createLabel(audioDeviceValue.getName()));
		}
	}

	private void createComponent(final FloatAudioDeviceValue facv) {
		final LabeledRotaryPotentiometerComponent comp = new LabeledRotaryPotentiometerComponent(facv.getName(), facv.getMidValue());
		RotaryPotentiometerImageComponent poti = comp.getPotentiometer();
		poti.setUnit(facv.getUnit());
		poti.setScale(facv.getScale());
		add(comp);
		
		Float minValue = facv.getMinValue();
		if (minValue != null) {
			poti.setMinValue(minValue);
		}

		Float maxValue = facv.getMaxValue();
		if (maxValue != null) {
			poti.setMaxValue(maxValue);
		}

		comp.setValue(facv.getValue());
		poti.addValueChangeListener(new RotaryPotentiometerValueChangeListener() {
			@Override
			public void rotaryPotentiometerValueChanged(float newValue, float oldValue) {
				facv.setValue(newValue);
			}
		});
		facv.addAudioDeviceValueListener(new AudioDeviceValueListener() {
			@Override
			public void audioDeviceValueChanged(AudioDevice audioDevice, AudioDeviceValue audioDeviceValue, String oldValue, String newValue) {
				comp.setValue(facv.getValue());
			}
		});
	}

	private void createComponent(final IntAudioDeviceValue iacv) {
		Float mid = iacv.getMidValue() == null ? null : (float) iacv.getMidValue();
		final LabeledRotaryPotentiometerComponent comp = new LabeledRotaryPotentiometerComponent(iacv.getName(), mid);
		RotaryPotentiometerImageComponent poti = comp.getPotentiometer();
		poti.setUnit(iacv.getUnit());
		poti.setIntegralValue(true);
		add(comp);

		Integer minValue = iacv.getMinValue();
		if (minValue != null) {
			poti.setMinValue(minValue);
		}

		Integer maxValue = iacv.getMaxValue();
		if (maxValue != null) {
			poti.setMaxValue(maxValue);
		}

		comp.setValue(iacv.getValue());
		poti.addValueChangeListener(new RotaryPotentiometerValueChangeListener() {
			@Override
			public void rotaryPotentiometerValueChanged(float newValue, float oldValue) {
				iacv.setValue((int) newValue);
			}
		});
		iacv.addAudioDeviceValueListener(new AudioDeviceValueListener() {
			@Override
			public void audioDeviceValueChanged(AudioDevice audioDevice, AudioDeviceValue audioDeviceValue, String oldValue, String newValue) {
				comp.setValue(iacv.getValue());
			}
		});
	}

	private void createComponent(final BooleanAudioDeviceValue bacv) {
		final JCheckBox check = new LightEmittingDiodeCheckBox(bacv.getName(), bacv.getValue(), 8, 8);
		check.setAlignmentX(CENTER_ALIGNMENT);
		
		bacv.addAudioDeviceValueListener(new AudioDeviceValueListener() {
			@Override
			public void audioDeviceValueChanged(AudioDevice audioDevice, AudioDeviceValue audioDeviceValue, String oldValue, String newValue) {
				check.setSelected(bacv.getValue());
			}
		});
		check.addActionListener(new ActionListener() {
			@Override
			public void actionPerformed(ActionEvent e) {
				bacv.setValue(check.isSelected());
			}
		});
		add(check);
	}

	private void createComponent(final EnumAudioDeviceValue<?> eacv) {
		final JComboBox<?> combo = createComboBox(eacv.getOptions());

		combo.setSelectedItem(eacv.getValue());
		combo.addActionListener(new ActionListener() {
			@Override
			public void actionPerformed(ActionEvent e) {
				eacv.setValueAsString(((Enum<?>) combo.getSelectedItem()).name());
			}
		});

		add(createLabel(eacv.getName()));
		add(combo);
		
		String value = eacv.getValueAsString();
		setToolTipText(value);
		combo.setToolTipText(value);
		eacv.addAudioDeviceValueListener(new AudioDeviceValueListener() {
			@Override
			public void audioDeviceValueChanged(AudioDevice audioDevice, AudioDeviceValue audioDeviceValue, String oldValue, String newValue) {
				String value = eacv.getValueAsString();
				setToolTipText(value);
				combo.setToolTipText(value);
				combo.setSelectedItem(eacv.getValue());
			}
		});
	}
	
	private void createComponent(final StringAudioDeviceValue sacv) {
		final JTextField textField = new JTextField(sacv.getValueAsString());
		textField.setAlignmentX(CENTER_ALIGNMENT);
		textField.setHorizontalAlignment(CENTER);
		Dimension dim = new Dimension(textField.getPreferredSize());
		dim.width = Integer.MAX_VALUE;
		textField.setMaximumSize(dim);
		textField.setBorder(null);
		textField.setOpaque(false);
		add(createLabel(sacv.getName()));
		add(textField);
		textField.addKeyListener(new KeyAdapter() {
			@Override
			public void keyReleased(KeyEvent e) {
				String text = textField.getText();
				if (text.trim().isEmpty()) {
					text = null;
				}
				sacv.setValueAsString(text);
			}
		});
		sacv.addAudioDeviceValueListener(new AudioDeviceValueListener() {
			@Override
			public void audioDeviceValueChanged(AudioDevice audioDevice, AudioDeviceValue audioDeviceValue, String oldValue, String newValue) {
				String value = sacv.getValueAsString();
				textField.setText(value);
			}
		});
	}

	private static JLabel createLabel(String text) {
		JLabel label = new JLabel(text);
		label.setAlignmentX(CENTER_ALIGNMENT);
		return label;
	}

}
